@@ -3,8 +3,8 @@
 #include "fastfetch.h"
 
 #define FF_DE_PRETTY_PLASMA "KDE Plasma"
-#define FF_DE_PRETTY_GNOME "Gnome"
-#define FF_DE_PRETTY_GNOME_CLASSIC "Gnome Classic"
+#define FF_DE_PRETTY_GNOME "GNOME"
+#define FF_DE_PRETTY_GNOME_CLASSIC "GNOME Classic"
 #define FF_DE_PRETTY_XFCE4 "Xfce4"
 #define FF_DE_PRETTY_CINNAMON "Cinnamon"
 #define FF_DE_PRETTY_MATE "Mate"
