@@ -1,16 +1,11 @@
 #pragma once
 
-#ifndef FF_INCLUDED_detection_font_font
-#define FF_INCLUDED_detection_font_font
-
 #include "fastfetch.h"
 
 #define FF_DETECT_FONT_NUM_FONTS 4
 
 typedef struct FFFontResult
 {
-    FFstrbuf error;
-
     /**
      * Linux / BSD: QT,      GTK2,  GTK3,        GTK4
      * MacOS:       System,  User,  System Mono, User Mono
@@ -21,6 +16,4 @@ typedef struct FFFontResult
     FFstrbuf display;
 } FFFontResult;
 
-const FFFontResult* ffDetectFont(const FFinstance* instance);
-
-#endif
+const char* ffDetectFont(FFFontResult* font);
