@@ -11,17 +11,21 @@ const char* ffDetectMemory(FFMemoryResult* ram)
     if (sysctl((int[]){ CTL_HW, HW_MEMSIZE }, 2, &ram->bytesTotal, &length, NULL, 0))
         return "Failed to read hw.memsize";
 
-    uint32_t pagesize;
-    length = sizeof(pagesize);
-    if (sysctl((int[]){ CTL_HW, HW_PAGESIZE }, 2, &pagesize, &length, NULL, 0))
-        return "Failed to read hw.pagesize";
-
     mach_msg_type_number_t count = HOST_VM_INFO64_COUNT;
     vm_statistics64_data_t vmstat;
     if(host_statistics64(mach_host_self(), HOST_VM_INFO64, (host_info64_t) (&vmstat), &count) != KERN_SUCCESS)
         return "Failed to read host_statistics64";
 
-    ram->bytesUsed = ((uint64_t) vmstat.active_count + vmstat.wire_count) * pagesize;
+    // https://github.com/exelban/stats/blob/master/Modules/RAM/readers.swift#L56
+    ram->bytesUsed = ((uint64_t)
+        + vmstat.active_count
+        + vmstat.inactive_count
+        + vmstat.speculative_count
+        + vmstat.wire_count
+        + vmstat.compressor_page_count
+        - vmstat.purgeable_count
+        - vmstat.external_page_count
+    ) * instance.state.platform.pageSize;
 
     return NULL;
 }
